@@ -76,7 +76,6 @@ plugins.append('greenballs')
 plugins.append('heavy-job')
 plugins.append('htmlpublisher')
 plugins.append('jenkins-multijob-plugin')
-plugins.append('jenkins-reviewbot')
 plugins.append('jobConfigHistory')
 plugins.append('job-dsl')
 plugins.append('mercurial')
@@ -84,6 +83,7 @@ plugins.append('msbuild')
 plugins.append('naginator')
 plugins.append('nodelabelparameter')
 plugins.append('parameterized-trigger')
+plugins.append('postbuildscript')
 plugins.append('show-build-parameters')
 plugins.append('sloccount')
 plugins.append('sidebar-link')
