@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "CardConnectionWorker.h"
@@ -105,6 +105,12 @@ void CardConnectionWorker::onKeepAliveTimeout()
 		return;
 	}
 
+	if (mReader->getReaderInfo().getCardInfo().getCardType() != CardType::SMART_EID)
+	{
+		qCDebug(card) << "No Smart-eID - Skipping keep alive";
+		return;
+	}
+
 	FileCommand command(FileRef::efCardAccess());
 	const auto& result = transmit(command);
 	if (result.mReturnCode == CardReturnCode::OK)
