@@ -1,11 +1,12 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "CVCertificateBody.h"
 
 #include "ASN1Util.h"
 #include "SecurityProtocol.h"
+#include "asn1/ASN1Struct.h"
 
 #include <QLoggingCategory>
 
@@ -23,54 +24,25 @@ ASN1_ITEM_TEMPLATE(CertificateProfileIdentifier) =
 			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x29, CertificateProfileIdentifier, ASN1_OCTET_STRING)
 ASN1_ITEM_TEMPLATE_END(CertificateProfileIdentifier)
 
-
-ASN1_SEQUENCE(CERTIFICATEEXTENSION_st) = {
-
-	ASN1_SIMPLE(CERTIFICATEEXTENSION_st, mOid, ASN1_OBJECT),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject1, ASN1_OCTET_STRING, 0x00),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject2, ASN1_OCTET_STRING, 0x01),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject3, ASN1_OCTET_STRING, 0x02),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject4, ASN1_OCTET_STRING, 0x03),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject5, ASN1_OCTET_STRING, 0x04),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject6, ASN1_OCTET_STRING, 0x05),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject7, ASN1_OCTET_STRING, 0x06),
-	ASN1_IMP_OPT(CERTIFICATEEXTENSION_st, mObject8, ASN1_OCTET_STRING, 0x07)
-}
-
-
-ASN1_SEQUENCE_END(CERTIFICATEEXTENSION_st)
-
-IMPLEMENT_ASN1_FUNCTIONS(CERTIFICATEEXTENSION)
-
-ASN1_ITEM_TEMPLATE(CERTIFICATEEXTENSION) =
-			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x13, CERTIFICATEEXTENSION, CERTIFICATEEXTENSION_st)
-ASN1_ITEM_TEMPLATE_END(CERTIFICATEEXTENSION)
-
-
-ASN1_ITEM_TEMPLATE(CERTIFICATEEXTENSIONS) =
-			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF | ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x05, CERTIFICATEEXTENSIONS, CERTIFICATEEXTENSION)
-ASN1_ITEM_TEMPLATE_END(CERTIFICATEEXTENSIONS)
-
+ASN1_ITEM_TEMPLATE(CAR) =
+			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x02, CAR, ASN1_OCTET_STRING)
+ASN1_ITEM_TEMPLATE_END(CAR)
 
 ASN1_ITEM_TEMPLATE(CHR) =
 			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x20, CHR, ASN1_OCTET_STRING)
 ASN1_ITEM_TEMPLATE_END(CHR)
 
-
-ASN1_ITEM_TEMPLATE(CAR) =
-			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x02, CAR, ASN1_OCTET_STRING)
-ASN1_ITEM_TEMPLATE_END(CAR)
-
+ASN1_ITEM_TEMPLATE(DATE_EFF) =
+			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x25, DATE, ASN1_OCTET_STRING)
+ASN1_ITEM_TEMPLATE_END(DATE_EFF)
 
 ASN1_ITEM_TEMPLATE(DATE_EXPIRE) =
 			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x24, DATE, ASN1_OCTET_STRING)
 ASN1_ITEM_TEMPLATE_END(DATE_EXPIRE)
 
-
-ASN1_ITEM_TEMPLATE(DATE_EFF) =
-			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x25, DATE, ASN1_OCTET_STRING)
-ASN1_ITEM_TEMPLATE_END(DATE_EFF)
-
+ASN1_ITEM_TEMPLATE(CERTIFICATEEXTENSIONS) =
+			ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF | ASN1_TFLG_IMPTAG | ASN1_TFLG_APPLICATION, 0x05, CERTIFICATEEXTENSIONS, ASN1_ANY)
+ASN1_ITEM_TEMPLATE_END(CERTIFICATEEXTENSIONS)
 
 ASN1_SEQUENCE(certificateprofilebody_st) = {
 	ASN1_SIMPLE(certificateprofilebody_st, mCertificateProfileIdentifier, CertificateProfileIdentifier),
@@ -173,18 +145,22 @@ QCryptographicHash::Algorithm CVCertificateBody::getHashAlgorithm() const
 }
 
 
-QHash<Oid, QByteArray> CVCertificateBody::getExtensions() const
+QByteArray CVCertificateBody::getExtension(const Oid& pOid) const
 {
-	QHash<Oid, QByteArray> ext;
-
-	if (mExtensions != nullptr)
+	if (mExtensions)
 	{
-		for (int i = 0; i < sk_CERTIFICATEEXTENSION_num(mExtensions); i++)
+		for (int i = 0; i < sk_ASN1_TYPE_num(mExtensions); i++)
 		{
-			const CERTIFICATEEXTENSION* extension = sk_CERTIFICATEEXTENSION_value(mExtensions, i);
-			ext.insert(Oid(extension->mOid), Asn1OctetStringUtil::getValue(extension->mObject1));
+			const ASN1Struct extension(Asn1TypeUtil::encode(sk_ASN1_TYPE_value(mExtensions, i)));
+			if (extension.getData(V_ASN1_UNIVERSAL, ASN1Struct::UNI_OBJECT_IDENTIFIER) == pOid.getData())
+			{
+				// Currently we only return the first simple ASN.1 value found in the structure. The
+				// only known case where more information is given is ID_SECTOR_PS (BSI TR-03110-3
+				// C.3.2.2). But this information is not used/requested by the eID-Client.
+				return extension.getData(V_ASN1_CONTEXT_SPECIFIC, ASN1Struct::CERTIFICATE_EXTENSION_CONTENT_0);
+			}
 		}
 	}
 
-	return ext;
+	return QByteArray();
 }
