@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2015-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2015-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -12,7 +12,7 @@
 
 #pragma once
 
-#include <QVector>
+#include <QList>
 #include <algorithm>
 #include <functional>
 
@@ -24,10 +24,10 @@ template<typename T>
 class ChainBuilder
 {
 	private:
-		QVector<QVector<T>> mChains;
+		QList<QList<T>> mChains;
 		std::function<bool(const T& pChild, const T& pParent)> mIsChildFunc;
 
-		void buildChain(const QVector<T>& pAllElements, const QVector<T>& pChain)
+		void buildChain(const QList<T>& pAllElements, const QList<T>& pChain)
 		{
 			bool chainComplete = true;
 
@@ -40,14 +40,14 @@ class ChainBuilder
 
 				if (mIsChildFunc(elem, pChain.last()))
 				{
-					QVector<T> extendedChain(pChain);
+					QList<T> extendedChain(pChain);
 					extendedChain += elem;
 					buildChain(pAllElements, extendedChain);
 					chainComplete = false;
 				}
 				else if (mIsChildFunc(pChain.first(), elem))
 				{
-					QVector<T> extendedChain({elem});
+					QList<T> extendedChain({elem});
 					extendedChain += pChain;
 					buildChain(pAllElements, extendedChain);
 					chainComplete = false;
@@ -61,28 +61,28 @@ class ChainBuilder
 		}
 
 
-		bool isSubChain(const QVector<T>& pSubChain)
+		bool isSubChain(const QList<T>& pSubChain)
 		{
-			return std::any_of(mChains.constBegin(), mChains.constEnd(), [&pSubChain] (const QVector<T>& pChain) {
+			return std::any_of(mChains.constBegin(), mChains.constEnd(), [&pSubChain] (const QList<T>& pChain) {
 					return std::search(pChain.constBegin(), pChain.constEnd(), pSubChain.constBegin(), pSubChain.constEnd())
 						   != pChain.constEnd();
 				});
 		}
 
 	protected:
-		QMutableVectorIterator<QVector<T>> getChainIterator()
+		QMutableListIterator<QList<T>> getChainIterator()
 		{
-			return QMutableVectorIterator<QVector<T>>(mChains);
+			return QMutableListIterator<QList<T>>(mChains);
 		}
 
 	public:
-		ChainBuilder(const QVector<T>& pAllElements, const std::function<bool(const T& pChild, const T& pParent)>& pIsChildFunc)
+		ChainBuilder(const QList<T>& pAllElements, const std::function<bool(const T& pChild, const T& pParent)>& pIsChildFunc)
 			: mChains()
 			, mIsChildFunc(pIsChildFunc)
 		{
 			for (const auto& elem : pAllElements)
 			{
-				const QVector<T> chain({elem});
+				const QList<T> chain({elem});
 				if (!isSubChain(chain))
 				{
 					buildChain(pAllElements, chain);
@@ -91,7 +91,7 @@ class ChainBuilder
 		}
 
 
-		const QVector<QVector<T>>& getChains() const
+		const QList<QList<T>>& getChains() const
 		{
 			return mChains;
 		}
