@@ -1,12 +1,12 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
 
 #include "asn1/CVCertificate.h"
 
-#include <QVector>
+#include <QList>
 
 namespace governikus
 {
@@ -14,12 +14,12 @@ namespace governikus
 class SignatureChecker
 {
 	private:
-		const QVector<QSharedPointer<const CVCertificate>> mCertificateChain;
+		const QList<QSharedPointer<const CVCertificate>> mCertificateChain;
 
 		bool checkSignature(const QSharedPointer<const CVCertificate>& pCert, const QSharedPointer<const CVCertificate>& pSigningCert, const EcdsaPublicKey* pKey) const;
 
 	public:
-		explicit SignatureChecker(const QVector<QSharedPointer<const CVCertificate>>& pCertificateChain);
+		explicit SignatureChecker(const QList<QSharedPointer<const CVCertificate>>& pCertificateChain);
 		~SignatureChecker() = default;
 
 		[[nodiscard]] bool check() const;
