@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2015-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2015-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "DestroyPaceChannelBuilder.h"
@@ -12,7 +12,7 @@
 using namespace governikus;
 
 
-QByteArray DestroyPaceChannelBuilder::createCommandData() const
+QByteArray DestroyPaceChannelBuilder::createASN1Struct() const
 {
 	// Command data according to PC/SC Part 10 amendment 1.1
 	static const char INDEX_DESTROY_PACE_CHANNEL = 0x03;
@@ -25,7 +25,7 @@ QByteArray DestroyPaceChannelBuilder::createCommandData() const
 }
 
 
-CommandApdu DestroyPaceChannelBuilder::createCommandDataCcid() const
+CommandApdu DestroyPaceChannelBuilder::createASN1StructCcid() const
 {
 	return CommandApdu(CCID_DESTROY_PACE_CHANNEL);
 }
