@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2016-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2016-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "ReaderDetector.h"
@@ -20,7 +20,7 @@ bool ReaderDetector::terminateNativeEvents()
 }
 
 
-QVector<UsbId> ReaderDetector::attachedDevIds() const
+QList<UsbId> ReaderDetector::attachedDevIds() const
 {
-	return QVector<UsbId>();
+	return QList<UsbId>();
 }
