@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*
@@ -11,9 +11,9 @@
 #include "EnumHelper.h"
 
 #include <QCoreApplication>
+#include <QList>
 #include <QPair>
 #include <QString>
-#include <QVector>
 
 #ifdef Q_OS_ANDROID
 	#include <QByteArrayList>
@@ -43,7 +43,7 @@ class BuildHelper
 		[[nodiscard]] static bool fetchUserInteractive();
 
 	public:
-		static QVector<QPair<QLatin1String, QString>> getInformationHeader();
+		static QList<QPair<QLatin1String, QString>> getInformationHeader();
 		static void processInformationHeader(const std::function<void(const QString&, const QString&)>& pFunc, bool pTranslate = true);
 
 		[[nodiscard]] static CertificateType getCertificateType();
