@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2017-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2017-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -24,7 +24,7 @@ class IfdConnectorImpl
 
 	private:
 		const int mConnectTimeoutMs;
-		QVector<QSharedPointer<ConnectRequest>> mPendingRequests;
+		QList<QSharedPointer<ConnectRequest>> mPendingRequests;
 
 		void removeRequest(const IfdDescriptor& pIfdDescriptor);
 
