@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 
@@ -21,29 +21,8 @@ AbstractSettings::AbstractSettings()
 }
 
 
-void AbstractSettings::save(const QSharedPointer<QSettings>& pSettings)
+QString AbstractSettings::getOrganization()
 {
-	pSettings->sync();
-	Backup::disable(pSettings);
-}
-
-
-QSharedPointer<QSettings> AbstractSettings::getStore(const QString& pFilename, QSettings::Format pFormat)
-{
-#ifndef QT_NO_DEBUG
-	if (QCoreApplication::applicationName().startsWith(QLatin1String("Test")))
-	{
-		if (mTestDir.isNull())
-		{
-			mTestDir.reset(new QTemporaryDir());
-			Q_ASSERT(mTestDir->isValid());
-		}
-		QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, mTestDir->path());
-		return QSharedPointer<QSettings>::create(QSettings::IniFormat, QSettings::UserScope, QCoreApplication::organizationName(), QStringLiteral("AusweisApp2"));
-	}
-#endif
-
-	Q_ASSERT(pFilename.isEmpty() == (pFormat == QSettings::InvalidFormat));
 #if defined(Q_OS_IOS) || defined(Q_OS_MACOS)
 	const auto& organization = QCoreApplication::organizationDomain();
 
@@ -52,5 +31,40 @@ QSharedPointer<QSettings> AbstractSettings::getStore(const QString& pFilename, Q
 
 #endif
 
-	return pFilename.isEmpty() ? QSharedPointer<QSettings>::create(organization, QStringLiteral("AusweisApp2")) : QSharedPointer<QSettings>::create(pFilename, pFormat);
+	return organization.isEmpty() ? QCoreApplication::applicationName() : organization;
+}
+
+
+void AbstractSettings::save(const QSharedPointer<QSettings>& pSettings)
+{
+	pSettings->sync();
+	Backup::disable(pSettings);
+}
+
+
+QSharedPointer<QSettings> AbstractSettings::getStore(QSettings::Scope pScope, const QString& pFilename, QSettings::Format pFormat)
+{
+#ifndef QT_NO_DEBUG
+	if (QCoreApplication::applicationName().startsWith(QLatin1StringView("Test")))
+	{
+		if (mTestDir.isNull())
+		{
+			mTestDir.reset(new QTemporaryDir());
+			Q_ASSERT(mTestDir->isValid());
+		}
+		QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, mTestDir->path());
+		return QSharedPointer<QSettings>::create(QSettings::IniFormat, QSettings::UserScope, getOrganization(), QCoreApplication::applicationName());
+	}
+#endif
+
+	Q_ASSERT(pFilename.isEmpty() == (pFormat == QSettings::InvalidFormat));
+	return pFilename.isEmpty()
+			   ? QSharedPointer<QSettings>::create(pScope, getOrganization(), QStringLiteral("AusweisApp2"))
+			   : QSharedPointer<QSettings>::create(pFilename, pFormat);
+}
+
+
+QSharedPointer<QSettings> AbstractSettings::getStore(const QString& pFilename, QSettings::Format pFormat)
+{
+	return getStore(QSettings::Scope::UserScope, pFilename, pFormat);
 }
