@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2022-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2022-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
@@ -30,9 +30,9 @@ class PortWrapper
 #ifdef Q_OS_WIN
 		static QString getUserOfProcessID(DWORD pPid);
 		static QString getExecutableOfProcessID(DWORD pPid);
-		static quint16 getPortOfRunningProcess(const QVector<MIB_TCPROW_OWNER_PID>& pConnections, const QString& pUser, quint16 pSelfPort, const in_addr& pRemoteAddr);
-		static QString getUserOfConnection(const QVector<MIB_TCPROW_OWNER_PID>& pConnections, quint16 pLocalPort, quint16 pRemotePort, const in_addr& pProxyAddr);
-		static QVector<MIB_TCPROW_OWNER_PID> getConnections();
+		static quint16 getPortOfRunningProcess(const QList<MIB_TCPROW_OWNER_PID>& pConnections, const QString& pUser, quint16 pSelfPort, const in_addr& pRemoteAddr);
+		static QString getUserOfConnection(const QList<MIB_TCPROW_OWNER_PID>& pConnections, quint16 pLocalPort, quint16 pRemotePort, const in_addr& pProxyAddr);
+		static QList<MIB_TCPROW_OWNER_PID> getConnections();
 		static quint16 getProcessPort(quint16 pLocalPort, quint16 pRemotePort);
 #else
 		static quint16 readPortFile(const QString& pFile);
