@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2019-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2019-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "AppUpdateDataModel.h"
@@ -169,15 +169,6 @@ const QString& AppUpdateDataModel::getNotes() const
 }
 
 
-void AppUpdateDataModel::skipUpdate() const
-{
-	if (isValid())
-	{
-		Env::getSingleton<AppUpdater>()->skipVersion(getVersion());
-	}
-}
-
-
 bool AppUpdateDataModel::download()
 {
 	mDownloadProgress = 0;
