@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2016-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2016-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "ApplicationModel.h"
@@ -226,6 +226,17 @@ qsizetype ApplicationModel::getAvailableReader() const
 }
 
 
+qsizetype ApplicationModel::getAvailablePcscReader() const
+{
+	if (!mContext)
+	{
+		return 0;
+	}
+
+	return Env::getSingleton<ReaderManager>()->getReaderInfos(ReaderFilter({ReaderManagerPlugInType::PCSC})).size();
+}
+
+
 bool ApplicationModel::isReaderTypeAvailable(ReaderManagerPlugInType pPlugInType) const
 {
 	if (!mContext)
