@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2021-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2021-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "SortedReaderModel.h"
@@ -10,18 +10,17 @@ using namespace governikus;
 
 bool SortedReaderModel::lessThan(const QModelIndex& source_left, const QModelIndex& source_right) const
 {
-
 	const auto& readerSupportedLeft = sourceModel()->data(source_left, ReaderModel::READER_SUPPORTED).toBool();
 	const auto& readerSupportedRight = sourceModel()->data(source_right, ReaderModel::READER_SUPPORTED).toBool();
 
-	const auto& readerInstalledLeft = sourceModel()->data(source_left, ReaderModel::READER_INSTALLED).toBool();
-	const auto& readerInstalledRight = sourceModel()->data(source_right, ReaderModel::READER_INSTALLED).toBool();
-
 	if (readerSupportedLeft == readerSupportedRight)
 	{
-		return readerInstalledLeft < readerInstalledRight;
+		const auto& readerInstalledLeft = sourceModel()->data(source_left, ReaderModel::READER_INSTALLED).toBool();
+		const auto& readerInstalledRight = sourceModel()->data(source_right, ReaderModel::READER_INSTALLED).toBool();
+
+		return !readerInstalledLeft && readerInstalledRight;
 	}
-	return readerSupportedLeft < readerSupportedRight;
+	return !readerSupportedLeft && readerSupportedRight;
 }
 
 
