@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2017-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2017-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "MockDataChannel.h"
@@ -61,7 +61,7 @@ void MockDataChannel::onReceived(const QByteArray& pDataBlock)
 }
 
 
-const QVector<QByteArray>& MockDataChannel::getReceivedDataBlocks() const
+const QList<QByteArray>& MockDataChannel::getReceivedDataBlocks() const
 {
 	return mReceivedDataBlocks;
 }
