@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2017-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2017-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -10,6 +10,7 @@
 
 #include <QtTest>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 class test_AccessRoleAndRight
@@ -99,44 +100,44 @@ class test_AccessRoleAndRight
 						right = pRight;
 					};
 
-			QVERIFY(!AccessRoleAndRightsUtil::fromTechnicalName(QString("crap"), func));
+			QVERIFY(!AccessRoleAndRightsUtil::fromTechnicalName("crap"_L1, func));
 			QCOMPARE(right, undefined);
 
-			QVERIFY(!AccessRoleAndRightsUtil::fromTechnicalName(QString("CAN_ALLOWED"), func));
+			QVERIFY(!AccessRoleAndRightsUtil::fromTechnicalName("CAN_ALLOWED"_L1, func));
 			QCOMPARE(right, undefined);
 
-			QVERIFY(!AccessRoleAndRightsUtil::fromTechnicalName(QString("familyname"), func));
+			QVERIFY(!AccessRoleAndRightsUtil::fromTechnicalName("familyname"_L1, func));
 			QCOMPARE(right, undefined);
 		}
 
 
 		void checkJoinFromTechnicalName()
 		{
-			auto data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType", "DoctoralDegree"});
+			auto data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType"_L1, "DoctoralDegree"_L1});
 			QCOMPARE(data, QStringLiteral("Document type, Doctoral degree"));
 
 			// previous versions stored translated display names instead of technical names, so be compatible here.
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"Alte Rechte", "FamilyName"});
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"Alte Rechte"_L1, "FamilyName"_L1});
 			QCOMPARE(data, QStringLiteral("Alte Rechte, Family name"));
 
 			// do not add "Alte Rechte" for WRITE only rights as previous version had no WRITE.
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"Alte Rechte", "FamilyName"}, AccessRoleAndRightsUtil::WRITE);
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"Alte Rechte"_L1, "FamilyName"_L1}, AccessRoleAndRightsUtil::WRITE);
 			QCOMPARE(data, QString());
 
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"Alte Rechte", "WriteCommunityID"}, AccessRoleAndRightsUtil::WRITE);
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"Alte Rechte"_L1, "WriteCommunityID"_L1}, AccessRoleAndRightsUtil::WRITE);
 			QCOMPARE(data, QStringLiteral("Community-ID"));
 
 			const auto right = AccessRoleAndRightsUtil::JoinRights(AccessRoleAndRightsUtil::READ | AccessRoleAndRightsUtil::WRITE);
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType", "WriteAddress"}, right);
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType"_L1, "WriteAddress"_L1}, right);
 			QCOMPARE(data, QStringLiteral("Document type, Address"));
 
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType", "WriteAddress"}, AccessRoleAndRightsUtil::READWRITE);
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType"_L1, "WriteAddress"_L1}, AccessRoleAndRightsUtil::READWRITE);
 			QCOMPARE(data, QStringLiteral("Document type, Address"));
 
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType", "WriteAddress"}, AccessRoleAndRightsUtil::WRITE);
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType"_L1, "WriteAddress"_L1}, AccessRoleAndRightsUtil::WRITE);
 			QCOMPARE(data, QStringLiteral("Address"));
 
-			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType", "WriteAddress"}, AccessRoleAndRightsUtil::READ);
+			data = AccessRoleAndRightsUtil::joinFromTechnicalName({"DocumentType"_L1, "WriteAddress"_L1}, AccessRoleAndRightsUtil::READ);
 			QCOMPARE(data, QStringLiteral("Document type"));
 		}
 
@@ -164,57 +165,57 @@ class test_AccessRoleAndRight
 		void test_ToDisplayText_data()
 		{
 			QTest::addColumn<AccessRight>("input");
-			QTest::addColumn<QString>("output");
+			QTest::addColumn<QLatin1String>("output");
 
-			const auto& reserved = QStringLiteral("Unknown (reserved)");
+			const auto& reserved = QLatin1String("Unknown (reserved)");
 			QTest::newRow("RFU_29") << AccessRight::RFU_29 << reserved;
 			QTest::newRow("RFU_30") << AccessRight::RFU_30 << reserved;
 			QTest::newRow("RFU_31") << AccessRight::RFU_31 << reserved;
 			QTest::newRow("RFU_32") << AccessRight::RFU_32 << reserved;
 
-			QTest::newRow("writeDG17") << AccessRight::WRITE_DG17 << QString("Address");
-			QTest::newRow("writeDG18") << AccessRight::WRITE_DG18 << QString("Community-ID");
-			QTest::newRow("writeDG19") << AccessRight::WRITE_DG19 << QString("Residence permit I");
-			QTest::newRow("writeDG20") << AccessRight::WRITE_DG20 << QString("Residence permit II");
-			QTest::newRow("writeDG21") << AccessRight::WRITE_DG21 << QString("Optional data");
-			QTest::newRow("readDG21") << AccessRight::READ_DG21 << QString("Optional data");
-			QTest::newRow("readDG20") << AccessRight::READ_DG20 << QString("Residence permit II");
-			QTest::newRow("readDG19") << AccessRight::READ_DG19 << QString("Residence permit I");
-			QTest::newRow("readDG18") << AccessRight::READ_DG18 << QString("Community-ID");
-			QTest::newRow("readDG17") << AccessRight::READ_DG17 << QString("Address");
-			QTest::newRow("readDG16") << AccessRight::READ_DG16 << QString("RFU");
-			QTest::newRow("readDG15") << AccessRight::READ_DG15 << QString("RFU");
-			QTest::newRow("readDG14") << AccessRight::READ_DG14 << QString("RFU");
-			QTest::newRow("readDG13") << AccessRight::READ_DG13 << QString("Birth name");
-			QTest::newRow("readDG12") << AccessRight::READ_DG12 << QString("Optional data");
-			QTest::newRow("readDG11") << AccessRight::READ_DG11 << QString("Gender");
-			QTest::newRow("readDG10") << AccessRight::READ_DG10 << QString("Nationality");
-			QTest::newRow("readDG09") << AccessRight::READ_DG09 << QString("Place of birth");
-			QTest::newRow("readDG08") << AccessRight::READ_DG08 << QString("Date of birth");
-			QTest::newRow("readDG07") << AccessRight::READ_DG07 << QString("Doctoral degree");
-			QTest::newRow("readDG06") << AccessRight::READ_DG06 << QString("Religious / artistic name");
-			QTest::newRow("readDG05") << AccessRight::READ_DG05 << QString("Family name");
-			QTest::newRow("readDG04") << AccessRight::READ_DG04 << QString("Given name(s)");
-			QTest::newRow("readDG03") << AccessRight::READ_DG03 << QString("Valid until");
-			QTest::newRow("readDG02") << AccessRight::READ_DG02 << QString("Issuing country");
-			QTest::newRow("readDG01") << AccessRight::READ_DG01 << QString("Document type");
-			QTest::newRow("installQualCert") << AccessRight::INSTALL_QUAL_CERT << QString("Installation of qualified signature certificates");
-			QTest::newRow("installCert") << AccessRight::INSTALL_CERT << QString("Installation of signature certificates");
-			QTest::newRow("pinManagement") << AccessRight::PIN_MANAGEMENT << QString("PIN Management");
-			QTest::newRow("canAllowed") << AccessRight::CAN_ALLOWED << QString("CAN allowed");
-			QTest::newRow("privilegedTerminal") << AccessRight::PRIVILEGED_TERMINAL << QString("Privileged terminal");
-			QTest::newRow("restrictedIdentification") << AccessRight::RESTRICTED_IDENTIFICATION << QString("Pseudonym");
-			QTest::newRow("comunityIdVerification") << AccessRight::COMMUNITY_ID_VERIFICATION << QString("Address verification");
-			QTest::newRow("ageVerification") << AccessRight::AGE_VERIFICATION << QString("Age verification");
+			QTest::newRow("writeDG17") << AccessRight::WRITE_DG17 << "Address"_L1;
+			QTest::newRow("writeDG18") << AccessRight::WRITE_DG18 << "Community-ID"_L1;
+			QTest::newRow("writeDG19") << AccessRight::WRITE_DG19 << "Residence permit I"_L1;
+			QTest::newRow("writeDG20") << AccessRight::WRITE_DG20 << "Residence permit II"_L1;
+			QTest::newRow("writeDG21") << AccessRight::WRITE_DG21 << "Optional data"_L1;
+			QTest::newRow("readDG21") << AccessRight::READ_DG21 << "Optional data"_L1;
+			QTest::newRow("readDG20") << AccessRight::READ_DG20 << "Residence permit II"_L1;
+			QTest::newRow("readDG19") << AccessRight::READ_DG19 << "Residence permit I"_L1;
+			QTest::newRow("readDG18") << AccessRight::READ_DG18 << "Community-ID"_L1;
+			QTest::newRow("readDG17") << AccessRight::READ_DG17 << "Address"_L1;
+			QTest::newRow("readDG16") << AccessRight::READ_DG16 << "RFU"_L1;
+			QTest::newRow("readDG15") << AccessRight::READ_DG15 << "RFU"_L1;
+			QTest::newRow("readDG14") << AccessRight::READ_DG14 << "RFU"_L1;
+			QTest::newRow("readDG13") << AccessRight::READ_DG13 << "Birth name"_L1;
+			QTest::newRow("readDG12") << AccessRight::READ_DG12 << "Optional data"_L1;
+			QTest::newRow("readDG11") << AccessRight::READ_DG11 << "Gender"_L1;
+			QTest::newRow("readDG10") << AccessRight::READ_DG10 << "Nationality"_L1;
+			QTest::newRow("readDG09") << AccessRight::READ_DG09 << "Place of birth"_L1;
+			QTest::newRow("readDG08") << AccessRight::READ_DG08 << "Date of birth"_L1;
+			QTest::newRow("readDG07") << AccessRight::READ_DG07 << "Doctoral degree"_L1;
+			QTest::newRow("readDG06") << AccessRight::READ_DG06 << "Religious / artistic name"_L1;
+			QTest::newRow("readDG05") << AccessRight::READ_DG05 << "Family name"_L1;
+			QTest::newRow("readDG04") << AccessRight::READ_DG04 << "Given name(s)"_L1;
+			QTest::newRow("readDG03") << AccessRight::READ_DG03 << "Valid until"_L1;
+			QTest::newRow("readDG02") << AccessRight::READ_DG02 << "Issuing country"_L1;
+			QTest::newRow("readDG01") << AccessRight::READ_DG01 << "Document type"_L1;
+			QTest::newRow("installQualCert") << AccessRight::INSTALL_QUAL_CERT << "Installation of qualified signature certificates"_L1;
+			QTest::newRow("installCert") << AccessRight::INSTALL_CERT << "Installation of signature certificates"_L1;
+			QTest::newRow("pinManagement") << AccessRight::PIN_MANAGEMENT << "PIN Management"_L1;
+			QTest::newRow("canAllowed") << AccessRight::CAN_ALLOWED << "CAN allowed"_L1;
+			QTest::newRow("privilegedTerminal") << AccessRight::PRIVILEGED_TERMINAL << "Privileged terminal"_L1;
+			QTest::newRow("restrictedIdentification") << AccessRight::RESTRICTED_IDENTIFICATION << "Pseudonym"_L1;
+			QTest::newRow("comunityIdVerification") << AccessRight::COMMUNITY_ID_VERIFICATION << "Address verification"_L1;
+			QTest::newRow("ageVerification") << AccessRight::AGE_VERIFICATION << "Age verification"_L1;
 
-			QTest::newRow("default") << static_cast<AccessRight>(100) << QString("Unknown");
+			QTest::newRow("default") << static_cast<AccessRight>(100) << "Unknown"_L1;
 		}
 
 
 		void test_ToDisplayText()
 		{
 			QFETCH(AccessRight, input);
-			QFETCH(QString, output);
+			QFETCH(QLatin1String, output);
 
 			QCOMPARE(AccessRoleAndRightsUtil::toDisplayText(input), output);
 		}
