@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -15,6 +15,7 @@
 #include <openssl/bn.h>
 
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 
@@ -30,7 +31,7 @@ class test_CVCertificate
 			return QByteArray();
 		}
 		int bufLen = BN_num_bytes(pBigNum);
-		QVector<uchar> buf(bufLen);
+		QList<uchar> buf(bufLen);
 		BN_bn2bin(pBigNum, buf.data());
 		return QByteArray(reinterpret_cast<char*>(buf.data()), bufLen);
 	}
@@ -39,7 +40,7 @@ class test_CVCertificate
 		void getRawBody()
 		{
 			QByteArray body("7f4e82016e5f290100420e44454356434165494430303130337f4982011d060a04007f000702020202038120a9fb57dba1eea9bc3e660a909d838d726e3bf623d52620282013481d1f6e537782207d5a0975fc2c3057eef67530417affe7fb8055c126dc5c6ce94a4b44f330b5d9832026dc5c6ce94a4b44f330b5d9bbd77cbf958416295cf7e1ce6bccdc18ff8c07b68441048bd2aeb9cb7e57cb2c4b482ffc81b7afb9de27e1e3bd23c23a4453bd9ace3262547ef835c3dac4fd97f8461a14611dc9c27745132ded8e545c1d54c72f0469978520a9fb57dba1eea9bc3e660a909d838d718c397aa3b561a6f7901e0e82974856a78641048925419fc7f194922cfc6b8dd25ae6a19c1b59216e6cf06270e5d75cfd64205f55cf867bbfefeefd6e680e1fd197f18ab684484901362568efc9adb5c6018d728701015f200e44454356434165494430303130337f4c12060904007f0007030102025305fc0f13ffff5f25060102010200035f2406010501020003");
-			QByteArray source = TestFileHelper::readFile(":/card/cvca-DECVCAeID00103.hex");
+			QByteArray source = TestFileHelper::readFile(":/card/cvca-DECVCAeID00103.hex"_L1);
 			auto cvc = CVCertificate::fromHex(source);
 
 			QCOMPARE(cvc->getRawBody(), QByteArray::fromHex(body));
@@ -49,7 +50,7 @@ class test_CVCertificate
 		void getRawSignature()
 		{
 			QByteArray signature("5f37406018cff8ee22ae417a63446a5fbf53ac39dd1ee331af4b62569604966f7575359b0c536673dcb98f9ae62c5f9724e0236bef6dc485ffa331be5e82de4410e2e8");
-			QByteArray source = TestFileHelper::readFile(":/card/cvca-DECVCAeID00103.hex");
+			QByteArray source = TestFileHelper::readFile(":/card/cvca-DECVCAeID00103.hex"_L1);
 			auto cvc = CVCertificate::fromHex(source);
 
 			QCOMPARE(cvc->getRawSignature(), QByteArray::fromHex(signature));
@@ -58,7 +59,7 @@ class test_CVCertificate
 
 		void toHex()
 		{
-			QByteArray source = TestFileHelper::readFile(":/card/cvca-DECVCAeID00103.hex");
+			QByteArray source = TestFileHelper::readFile(":/card/cvca-DECVCAeID00103.hex"_L1);
 			auto cvc = CVCertificate::fromHex(source);
 
 			QCOMPARE(cvc->encode().toHex(), source);
@@ -81,7 +82,7 @@ class test_CVCertificate
 
 		void testIsValidOn()
 		{
-			QByteArray source = TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex");
+			QByteArray source = TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1);
 			auto cvc = CVCertificate::fromHex(source);
 
 			QVERIFY(!cvc->isValidOn(QDateTime(QDate(2010, 8, 12), QTime(22, 59, 59, 999), Qt::OffsetFromUTC, -60 * 60 * 1)));
@@ -100,15 +101,15 @@ class test_CVCertificate
 
 		void testSuccess()
 		{
-			QByteArray source = TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex");
+			QByteArray source = TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1);
 			QVERIFY(CVCertificate::fromHex(source) != nullptr);
 		}
 
 
 		void testIsIssuedBy()
 		{
-			auto cvca1 = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"));
-			auto cvcaLink2_1 = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00002_DETESTeID00001.hex"));
+			auto cvca1 = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1));
+			auto cvcaLink2_1 = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00002_DETESTeID00001.hex"_L1));
 
 			QVERIFY(cvca1->isIssuedBy(*cvca1));
 			QVERIFY(cvcaLink2_1->isIssuedBy(*cvca1));
@@ -118,7 +119,7 @@ class test_CVCertificate
 
 		void getEcdsaSignature()
 		{
-			auto cvca1 = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"));
+			auto cvca1 = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1));
 
 			auto ecdsaSignature = cvca1->getEcdsaSignature();
 			const BIGNUM* r = nullptr;
@@ -136,7 +137,7 @@ class test_CVCertificate
 			const QRegularExpression output(QRegularExpression::escape(regex));
 
 			QTest::ignoreMessage(QtDebugMsg, output);
-			QSharedPointer<const CVCertificate> cvca = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"));
+			QSharedPointer<const CVCertificate> cvca = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1));
 			qDebug() << cvca;
 
 			QTest::ignoreMessage(QtDebugMsg, output);
@@ -144,19 +145,19 @@ class test_CVCertificate
 			qDebug() << cvcsNonConst;
 
 			QTest::ignoreMessage(QtDebugMsg, output);
-			QVector<QSharedPointer<CVCertificate>> cvcsVector = {qSharedPointerConstCast<CVCertificate>(cvca)};
+			QList<QSharedPointer<CVCertificate>> cvcsVector = {qSharedPointerConstCast<CVCertificate>(cvca)};
 			qDebug() << cvcsVector;
 
 			QTest::ignoreMessage(QtDebugMsg, output);
-			QVector<QSharedPointer<const CVCertificate>> cvcsVectorConst({cvca});
+			QList<QSharedPointer<const CVCertificate>> cvcsVectorConst({cvca});
 			qDebug() << cvcsVectorConst;
 		}
 
 
 		void equals()
 		{
-			QSharedPointer<const CVCertificate> cvca1_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"));
-			QSharedPointer<const CVCertificate> cvca2_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"));
+			QSharedPointer<const CVCertificate> cvca1_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1));
+			QSharedPointer<const CVCertificate> cvca2_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1));
 			QSharedPointer<CVCertificate> cvca1 = qSharedPointerConstCast<CVCertificate>(cvca1_const);
 			QSharedPointer<CVCertificate> cvca2 = qSharedPointerConstCast<CVCertificate>(cvca2_const);
 
@@ -171,8 +172,8 @@ class test_CVCertificate
 
 		void notEquals()
 		{
-			QSharedPointer<const CVCertificate> cvca1_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"));
-			QSharedPointer<const CVCertificate> cvca2_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00002.hex"));
+			QSharedPointer<const CVCertificate> cvca1_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00001.hex"_L1));
+			QSharedPointer<const CVCertificate> cvca2_const = CVCertificate::fromHex(TestFileHelper::readFile(":/card/cvca-DETESTeID00002.hex"_L1));
 			QSharedPointer<CVCertificate> cvca1 = qSharedPointerConstCast<CVCertificate>(cvca1_const);
 			QSharedPointer<CVCertificate> cvca2 = qSharedPointerConstCast<CVCertificate>(cvca2_const);
 
