@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2018-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2018-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -12,6 +12,7 @@
 
 #include <QtTest>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 class test_DiagnosisModel
@@ -27,17 +28,17 @@ class test_DiagnosisModel
 			const QByteArray rawData = TestFileHelper::readFile(filePath);
 			QString stringData = QString::fromUtf8(rawData);
 
-			Q_ASSERT(stringData.count("\r\n") == 0);
-			const qsizetype linebreaks = stringData.count('\n');
-			stringData.replace('\n', "\r\n");
-			Q_ASSERT(stringData.count("\r\n") == linebreaks);
+			Q_ASSERT(stringData.count("\r\n"_L1) == 0);
+			const qsizetype linebreaks = stringData.count('\n'_L1);
+			stringData.replace('\n'_L1, "\r\n"_L1);
+			Q_ASSERT(stringData.count("\r\n"_L1) == linebreaks);
 
 			return stringData;
 		}
 
 
 		bool verifyOrder(const QSharedPointer<SectionModel>& pSection,
-			const QVector<QVector<ContentItem>>& pOrder)
+			const QList<QList<ContentItem>>& pOrder)
 		{
 			const auto& content = pSection->mContentItems;
 			qsizetype offset = 0;
@@ -72,18 +73,18 @@ class test_DiagnosisModel
 			QCOMPARE(mModel->rowCount(), mModel->mSections.size());
 
 			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::GENERAL), QCoreApplication::applicationName());
-			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::READER), QString("Card reader"));
-			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::NETWORK), QString("Network"));
-			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::SECURITY), QString("Antivirus and firewall"));
+			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::READER), "Card reader"_L1);
+			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::NETWORK), "Network"_L1);
+			QCOMPARE(mModel->getSectionName(DiagnosisModel::Section::SECURITY), "Antivirus and firewall"_L1);
 
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::GENERAL]->mContentItems.last().mTitle, QString("Time of diagnosis"));
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::GENERAL]->mContentItems.last().mTitle, "Time of diagnosis"_L1);
 
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(0).mTitle, QString("Paired smartphones"));
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(1).mContent, QString("No devices paired."));
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(2).mTitle, QString("Card reader"));
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(3).mContent, QString("Diagnosis is running..."));
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(4).mTitle, QString("PC/SC driver information"));
-			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(5).mContent, QString("Diagnosis is running..."));
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(0).mTitle, "Paired smartphones"_L1);
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(1).mContent, "No devices paired."_L1);
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(2).mTitle, "Card reader"_L1);
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(3).mContent, "Diagnosis is running..."_L1);
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(4).mTitle, "PC/SC driver information"_L1);
+			QCOMPARE(mModel->mSections[DiagnosisModel::Section::READER]->mContentItems.at(5).mContent, "Diagnosis is running..."_L1);
 
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::READER],
 					{mModel->mRemoteDeviceSection, mModel->mCardReaderSection, mModel->mPcscSection}));
@@ -98,27 +99,27 @@ class test_DiagnosisModel
 		{
 			mModel->onReaderInfosChanged();
 			QCOMPARE(mModel->mCardReaderSection.size(), 2);
-			QCOMPARE(mModel->mCardReaderSection.at(1).mContent, QString("No supported reader found."));
+			QCOMPARE(mModel->mCardReaderSection.at(1).mContent, "No supported reader found."_L1);
 
 			ReaderInfo defaultInfo;
-			ReaderInfo infoEidCard(QString("testInfo"), ReaderManagerPlugInType::PCSC, CardInfo(CardType::EID_CARD));
-			ReaderInfo comfortReaderInfo(QString("name"), ReaderManagerPlugInType::REMOTE_IFD, CardInfo(CardType::UNKNOWN));
+			ReaderInfo infoEidCard("testInfo"_L1, ReaderManagerPlugInType::PCSC, CardInfo(CardType::EID_CARD));
+			ReaderInfo comfortReaderInfo("name"_L1, ReaderManagerPlugInType::REMOTE_IFD, CardInfo(CardType::UNKNOWN));
 			comfortReaderInfo.setBasicReader(false);
-			const QVector<ReaderInfo> readerInfos = {defaultInfo, infoEidCard, comfortReaderInfo};
+			const QList<ReaderInfo> readerInfos = {defaultInfo, infoEidCard, comfortReaderInfo};
 			mModel->mContext->setReaderInfos(readerInfos);
 			mModel->onReaderInfosChanged();
 
 			QCOMPARE(mModel->mCardReaderSection.size(), 4);
 
-			QCOMPARE(mModel->mCardReaderSection.at(0).mTitle, QString("Connected Card readers"));
+			QCOMPARE(mModel->mCardReaderSection.at(0).mTitle, "Connected Card readers"_L1);
 			QCOMPARE(mModel->mCardReaderSection.at(1).mTitle, QString());
-			QCOMPARE(mModel->mCardReaderSection.at(2).mTitle, QString("testInfo"));
-			QCOMPARE(mModel->mCardReaderSection.at(3).mTitle, QString("name"));
+			QCOMPARE(mModel->mCardReaderSection.at(2).mTitle, "testInfo"_L1);
+			QCOMPARE(mModel->mCardReaderSection.at(3).mTitle, "name"_L1);
 
 			QCOMPARE(mModel->mCardReaderSection.at(0).mContent, QString());
-			QCOMPARE(mModel->mCardReaderSection.at(1).mContent, QString("Type: Basic card reader\nCard: not inserted"));
-			QCOMPARE(mModel->mCardReaderSection.at(2).mContent, QString("Type: Basic card reader\nCard: ID card (PA/eAT/eID)\nRetry counter: -1"));
-			QCOMPARE(mModel->mCardReaderSection.at(3).mContent, QString("Type: Standard / comfort card reader\nCard: unknown type"));
+			QCOMPARE(mModel->mCardReaderSection.at(1).mContent, "Type: Basic card reader\nCard: not inserted"_L1);
+			QCOMPARE(mModel->mCardReaderSection.at(2).mContent, "Type: Basic card reader\nCard: ID card (PA/eAT/eID)\nRetry counter: -1"_L1);
+			QCOMPARE(mModel->mCardReaderSection.at(3).mContent, "Type: Standard / comfort card reader\nCard: unknown type"_L1);
 
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::READER], {
 						mModel->mRemoteDeviceSection,
@@ -131,8 +132,8 @@ class test_DiagnosisModel
 		{
 			mModel->onRemoteInfosChanged();
 			QCOMPARE(mModel->mRemoteDeviceSection.size(), 2);
-			QCOMPARE(mModel->mRemoteDeviceSection.at(0).mTitle, QString("Paired smartphones"));
-			QCOMPARE(mModel->mRemoteDeviceSection.at(1).mContent, QString("No devices paired."));
+			QCOMPARE(mModel->mRemoteDeviceSection.at(0).mTitle, "Paired smartphones"_L1);
+			QCOMPARE(mModel->mRemoteDeviceSection.at(1).mContent, "No devices paired."_L1);
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::READER], {
 						mModel->mRemoteDeviceSection,
 						mModel->mCardReaderSection,
@@ -142,24 +143,24 @@ class test_DiagnosisModel
 
 		void test_OnPcscInfoChanged()
 		{
-			const QString version("Version");
-			const DiagnosisContext::ComponentInfo component1(QString("/path/to/component1"), QString("description1"), QString("version1"), QString("vendor1"));
-			const DiagnosisContext::ComponentInfo component2(QString("/path/to/component2"), QString("description2"), QString("version2"), QString("vendor2"));
-			const DiagnosisContext::ComponentInfo driver1(QString("/path/to/driver1"), QString("description1"), QString("version1"), QString("vendor1"));
-			const DiagnosisContext::ComponentInfo driver2(QString("/path/to/driver2"), QString("description2"), QString("version2"), QString("vendor2"));
-			QVector<DiagnosisContext::ComponentInfo> components = {component1, component2};
-			QVector<DiagnosisContext::ComponentInfo> drivers = {driver1, driver2};
+			const QString version("Version"_L1);
+			const DiagnosisContext::ComponentInfo component1("/path/to/component1"_L1, "description1"_L1, "version1"_L1, "vendor1"_L1);
+			const DiagnosisContext::ComponentInfo component2("/path/to/component2"_L1, "description2"_L1, "version2"_L1, "vendor2"_L1);
+			const DiagnosisContext::ComponentInfo driver1("/path/to/driver1"_L1, "description1"_L1, "version1"_L1, "vendor1"_L1);
+			const DiagnosisContext::ComponentInfo driver2("/path/to/driver2"_L1, "description2"_L1, "version2"_L1, "vendor2"_L1);
+			QList<DiagnosisContext::ComponentInfo> components = {component1, component2};
+			QList<DiagnosisContext::ComponentInfo> drivers = {driver1, driver2};
 			mModel->mContext->setPcscInfo(version, components, drivers);
 			mModel->onPcscInfoChanged();
 
 			QCOMPARE(mModel->mPcscSection.size(), 4);
 
-			QCOMPARE(mModel->mPcscSection.at(0).mTitle, QString("PC/SC information"));
-			QCOMPARE(mModel->mPcscSection.at(1).mContent, QString("Version"));
-			QCOMPARE(mModel->mPcscSection.at(2).mTitle, QString("Components"));
-			QCOMPARE(mModel->mPcscSection.at(2).mContent, QString("description1\nVendor: vendor1\nVersion: version1\nFile path: /path/to/component1\ndescription2\nVendor: vendor2\nVersion: version2\nFile path: /path/to/component2"));
-			QCOMPARE(mModel->mPcscSection.at(3).mTitle, QString("Driver"));
-			QCOMPARE(mModel->mPcscSection.at(3).mContent, QString("description1\nVendor: vendor1\nVersion: version1\nFile path: /path/to/driver1\ndescription2\nVendor: vendor2\nVersion: version2\nFile path: /path/to/driver2"));
+			QCOMPARE(mModel->mPcscSection.at(0).mTitle, "PC/SC information"_L1);
+			QCOMPARE(mModel->mPcscSection.at(1).mContent, "Version"_L1);
+			QCOMPARE(mModel->mPcscSection.at(2).mTitle, "Components"_L1);
+			QCOMPARE(mModel->mPcscSection.at(2).mContent, "description1\nVendor: vendor1\nVersion: version1\nFile path: /path/to/component1\ndescription2\nVendor: vendor2\nVersion: version2\nFile path: /path/to/component2"_L1);
+			QCOMPARE(mModel->mPcscSection.at(3).mTitle, "Driver"_L1);
+			QCOMPARE(mModel->mPcscSection.at(3).mContent, "description1\nVendor: vendor1\nVersion: version1\nFile path: /path/to/driver1\ndescription2\nVendor: vendor2\nVersion: version2\nFile path: /path/to/driver2"_L1);
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::READER], {
 						mModel->mRemoteDeviceSection,
 						mModel->mCardReaderSection,
@@ -176,13 +177,13 @@ class test_DiagnosisModel
 
 			mModel->mContext->setTimestamp(invalid);
 			mModel->onTimestampChanged();
-			QCOMPARE(mModel->mTimestampSection.last().mTitle, QString("Time of diagnosis"));
-			QCOMPARE(mModel->mTimestampSection.last().mContent, QString("Failed to retrieve date & time"));
+			QCOMPARE(mModel->mTimestampSection.last().mTitle, "Time of diagnosis"_L1);
+			QCOMPARE(mModel->mTimestampSection.last().mContent, "Failed to retrieve date & time"_L1);
 
 			mModel->mContext->setTimestamp(valid);
 			mModel->onTimestampChanged();
-			QCOMPARE(mModel->mTimestampSection.last().mTitle, QString("Time of diagnosis"));
-			QCOMPARE(mModel->mTimestampSection.last().mContent, QString("12. October 2018, 12:00:00 PM"));
+			QCOMPARE(mModel->mTimestampSection.last().mTitle, "Time of diagnosis"_L1);
+			QCOMPARE(mModel->mTimestampSection.last().mContent, "12. October 2018, 12:00:00 PM"_L1);
 		}
 
 
@@ -198,8 +199,8 @@ class test_DiagnosisModel
 			QCOMPARE(mModel->mNetworkInterfaceSection.size(), 3);
 			for (const auto& item : std::as_const(mModel->mNetworkInterfaceSection))
 			{
-				QCOMPARE(item.mTitle, QString(""));
-				QCOMPARE(item.mContent, QString("Hardware address: <Not set>\nNo IP addresses assigned"));
+				QCOMPARE(item.mTitle, QString());
+				QCOMPARE(item.mContent, "Hardware address: <Not set>\nNo IP addresses assigned"_L1);
 			}
 
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::NETWORK], {mModel->mNetworkConnectionSection, mModel->mNetworkInterfaceSection}));
@@ -210,8 +211,8 @@ class test_DiagnosisModel
 		{
 			mModel->onAntivirusDetectionFailed();
 			QCOMPARE(mModel->mAntivirusSection.size(), 1);
-			QCOMPARE(mModel->mAntivirusSection.at(0).mTitle, QString("Antivirus information"));
-			QCOMPARE(mModel->mAntivirusSection.at(0).mContent, QString("Antivirus detection failed."));
+			QCOMPARE(mModel->mAntivirusSection.at(0).mTitle, "Antivirus information"_L1);
+			QCOMPARE(mModel->mAntivirusSection.at(0).mContent, "Antivirus detection failed."_L1);
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::SECURITY], {mModel->mAntivirusSection, mModel->mFirewallSection}));
 		}
 
@@ -220,8 +221,8 @@ class test_DiagnosisModel
 		{
 			mModel->onAntivirusInformationChanged();
 			QCOMPARE(mModel->mAntivirusSection.size(), 1);
-			QCOMPARE(mModel->mAntivirusSection.at(0).mTitle, QString("Antivirus information"));
-			QCOMPARE(mModel->mAntivirusSection.at(0).mContent, QString("No Antivirus software detected."));
+			QCOMPARE(mModel->mAntivirusSection.at(0).mTitle, "Antivirus information"_L1);
+			QCOMPARE(mModel->mAntivirusSection.at(0).mContent, "No Antivirus software detected."_L1);
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::SECURITY], {mModel->mAntivirusSection, mModel->mFirewallSection}));
 
 			const QString& fileContent = getTestData(QStringLiteral("antivir_two_antivirus.txt"));
@@ -229,11 +230,11 @@ class test_DiagnosisModel
 			mModel->onAntivirusInformationChanged();
 
 			QCOMPARE(mModel->mAntivirusSection.size(), 3);
-			QCOMPARE(mModel->mAntivirusSection.at(0).mTitle, QString("Antivirus information"));
-			QCOMPARE(mModel->mAntivirusSection.at(1).mTitle, QString("BullGuard Antivirus"));
-			QCOMPARE(mModel->mAntivirusSection.at(1).mContent, QString("Last updated: Fri, 30 Nov 2018 15:04:13 GMT\nExecutable path: C:\\Program Files\\BullGuard Ltd\\BullGuard\\BullGuard.exe"));
-			QCOMPARE(mModel->mAntivirusSection.at(2).mTitle, QString("Windows Defender"));
-			QCOMPARE(mModel->mAntivirusSection.at(2).mContent, QString("Last updated: Mon, 26 Nov 2018 10:34:23 GMT\nExecutable path: windowsdefender://"));
+			QCOMPARE(mModel->mAntivirusSection.at(0).mTitle, "Antivirus information"_L1);
+			QCOMPARE(mModel->mAntivirusSection.at(1).mTitle, "BullGuard Antivirus"_L1);
+			QCOMPARE(mModel->mAntivirusSection.at(1).mContent, "Last updated: Fri, 30 Nov 2018 15:04:13 GMT\nExecutable path: C:\\Program Files\\BullGuard Ltd\\BullGuard\\BullGuard.exe"_L1);
+			QCOMPARE(mModel->mAntivirusSection.at(2).mTitle, "Windows Defender"_L1);
+			QCOMPARE(mModel->mAntivirusSection.at(2).mContent, "Last updated: Mon, 26 Nov 2018 10:34:23 GMT\nExecutable path: windowsdefender://"_L1);
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::SECURITY], {mModel->mAntivirusSection, mModel->mFirewallSection}));
 		}
 
@@ -242,8 +243,8 @@ class test_DiagnosisModel
 		{
 			mModel->onFirewallInformationFailed();
 			QCOMPARE(mModel->mFirewallSection.size(), 1);
-			QCOMPARE(mModel->mFirewallSection.at(0).mTitle, QString("Firewall information"));
-			QCOMPARE(mModel->mFirewallSection.at(0).mContent, QString("An error occurred while trying to gather firewall information. Please check the log for more information."));
+			QCOMPARE(mModel->mFirewallSection.at(0).mTitle, "Firewall information"_L1);
+			QCOMPARE(mModel->mFirewallSection.at(0).mContent, "An error occurred while trying to gather firewall information. Please check the log for more information."_L1);
 			QVERIFY(verifyOrder(mModel->mSections[DiagnosisModel::Section::SECURITY], {mModel->mAntivirusSection, mModel->mFirewallSection}));
 		}
 
@@ -269,30 +270,41 @@ class test_DiagnosisModel
 			QFETCH(bool, connectionTestOnProxy);
 			QFETCH(bool, connectionTestWithoutProxy);
 
+			const auto errorString = "Testerror"_L1;
+
 			mModel->mConnectionTest.mIsProxySet = proxySet;
 			mModel->mConnectionTest.mPingTestOnProxySuccessful = pingTestOnProxy;
 			mModel->mConnectionTest.mConnectionTestWithProxySuccessful = connectionTestOnProxy;
 			mModel->mConnectionTest.mConnectionTestWithoutProxySuccessful = connectionTestWithoutProxy;
+			if (proxySet && !connectionTestOnProxy)
+			{
+				mModel->mConnectionTest.mErrorOfConnectionTestWithProxy = errorString;
+			}
 
 			mModel->onConnectionTestDone();
 			QCOMPARE(mModel->mNetworkConnectionSection.size(), 2);
-			QCOMPARE(mModel->mNetworkConnectionSection.at(0).mTitle, QString("Service addresses"));
-			QCOMPARE(mModel->mNetworkConnectionSection.at(1).mTitle, QString("Proxy information"));
+			QCOMPARE(mModel->mNetworkConnectionSection.at(0).mTitle, "Service addresses"_L1);
+			QCOMPARE(mModel->mNetworkConnectionSection.at(1).mTitle, "Proxy information"_L1);
 
 			QString contentString;
 			if (proxySet)
 			{
-				contentString = QString("Hostname: \nPort: \nType: \nCapabilities: \nPing test to proxy: ");
-				contentString += pingTestOnProxy ? QString("Successful") : QString("Failed");
-				contentString += QString("\nConnection test with proxy: ");
-				contentString += connectionTestOnProxy ? QString("Successful") : QString("Failed");
+				contentString = "Hostname: \nPort: \nType: \nCapabilities: \nPing test to proxy: "_L1;
+				contentString += pingTestOnProxy ? "Successful"_L1 : "Failed"_L1;
+				contentString += "\nConnection test with proxy: "_L1;
+				contentString += connectionTestOnProxy ? "Successful"_L1 : "Failed"_L1;
+				if (!connectionTestOnProxy)
+				{
+					contentString += "\nEncountered error: "_L1;
+					contentString += errorString;
+				}
 			}
 			else
 			{
-				contentString = QString("No proxy found");
+				contentString = "No proxy found"_L1;
 			}
-			contentString += QString("\nConnection test without proxy: ");
-			contentString += connectionTestWithoutProxy ? QString("Successful") : QString("Failed");
+			contentString += "\nConnection test without proxy: "_L1;
+			contentString += connectionTestWithoutProxy ? "Successful"_L1 : "Failed"_L1;
 
 			QCOMPARE(mModel->mNetworkConnectionSection.at(0).mContent, QStringLiteral("Not bound"));
 			QCOMPARE(mModel->mNetworkConnectionSection.at(1).mContent, contentString);
@@ -302,7 +314,7 @@ class test_DiagnosisModel
 
 		void test_SavePlainText()
 		{
-			static const QRegularExpression re(R"(^Test_diagnosis_DiagnosisModel\r?
+			static const QRegularExpression re(QLatin1StringView(R"(^Test_diagnosis_DiagnosisModel\r?
 Application\r?
 Test_diagnosis_DiagnosisModel\r?
 Application Version\r?
@@ -340,7 +352,7 @@ Antivirus and firewall\r?
 Antivirus information\r?
 .+\r?
 Firewall information\r?
-.+)");
+.+)"));
 			QVERIFY(re.match(mModel->getAsPlaintext()).hasMatch());
 
 			QTemporaryFile file;
