@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2018-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2018-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "messages/IfdDisconnect.h"
@@ -8,7 +8,7 @@
 
 #include <QtTest>
 
-
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 
@@ -36,11 +36,11 @@ class test_IfdDisconnect
 			QVERIFY(msg.isIncomplete());
 
 			QCOMPARE(logSpy.count(), 5);
-			QVERIFY(logSpy.at(0).at(0).toString().contains("Missing value \"msg\""));
-			QVERIFY(logSpy.at(1).at(0).toString().contains("Invalid messageType received: \"\""));
-			QVERIFY(logSpy.at(2).at(0).toString().contains("Missing value \"ContextHandle\""));
-			QVERIFY(logSpy.at(3).at(0).toString().contains("Missing value \"SlotHandle\""));
-			QVERIFY(logSpy.at(4).at(0).toString().contains("The value of msg should be IFDDisconnect"));
+			QVERIFY(logSpy.at(0).at(0).toString().contains("Missing value \"msg\""_L1));
+			QVERIFY(logSpy.at(1).at(0).toString().contains("Invalid messageType received: \"\""_L1));
+			QVERIFY(logSpy.at(2).at(0).toString().contains("Missing value \"ContextHandle\""_L1));
+			QVERIFY(logSpy.at(3).at(0).toString().contains("Missing value \"SlotHandle\""_L1));
+			QVERIFY(logSpy.at(4).at(0).toString().contains("The value of msg should be IFDDisconnect"_L1));
 		}
 
 
@@ -142,14 +142,14 @@ class test_IfdDisconnect
 			if (type == IfdMessageType::UNDEFINED)
 			{
 				QCOMPARE(logSpy.count(), 2);
-				QVERIFY(logSpy.at(0).at(0).toString().contains("Invalid messageType received: \"UNDEFINED\""));
-				QVERIFY(logSpy.at(1).at(0).toString().contains("The value of msg should be IFDDisconnect"));
+				QVERIFY(logSpy.at(0).at(0).toString().contains("Invalid messageType received: \"UNDEFINED\""_L1));
+				QVERIFY(logSpy.at(1).at(0).toString().contains("The value of msg should be IFDDisconnect"_L1));
 
 				return;
 			}
 
 			QCOMPARE(logSpy.count(), 1);
-			QVERIFY(logSpy.at(0).at(0).toString().contains("The value of msg should be IFDDisconnect"));
+			QVERIFY(logSpy.at(0).at(0).toString().contains("The value of msg should be IFDDisconnect"_L1));
 		}
 
 
@@ -171,7 +171,7 @@ class test_IfdDisconnect
 			QCOMPARE(ifdDisconnect.getSlotHandle(), QString());
 
 			QCOMPARE(logSpy.count(), 1);
-			QVERIFY(logSpy.at(0).at(0).toString().contains("The value of \"SlotHandle\" should be of type \"string\""));
+			QVERIFY(logSpy.at(0).at(0).toString().contains("The value of \"SlotHandle\" should be of type \"string\""_L1));
 		}
 
 
