@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2016-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2016-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -18,6 +18,7 @@
 
 #include <QtTest>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 class test_MsgContext
@@ -94,7 +95,7 @@ class test_MsgContext
 			QVERIFY(!ctx.getContext<AuthContext>());
 			QVERIFY(!readOnly.getContext());
 
-			ctx.setWorkflowContext(QSharedPointer<AuthContext>(new AuthContext(true, QUrl("http://www.bla.de"))));
+			ctx.setWorkflowContext(QSharedPointer<AuthContext>(new AuthContext(true, QUrl("http://www.bla.de"_L1))));
 			QVERIFY(readOnly.isActiveWorkflow());
 			QVERIFY(readOnly.getContext<AuthContext>());
 			QVERIFY(ctx.getContext<AuthContext>());
