@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2017-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2017-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "ReaderModel.h"
@@ -12,7 +12,7 @@
 
 #include <QtTest>
 
-
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 
@@ -22,27 +22,46 @@ class MockReaderManager
 	Q_OBJECT
 
 	private:
-		const QVector<ReaderInfo>& mReaderInfos;
+		const QList<ReaderInfo>& mReaderInfos;
+		bool mIsScanRunning;
 
 	public:
-		MockReaderManager(const QVector<ReaderInfo>& pReaderInfos);
-		QVector<ReaderInfo> getReaderInfos(const ReaderFilter& pFilter = ReaderFilter()) const override;
+		MockReaderManager(const QList<ReaderInfo>& pReaderInfos);
+		ReaderManagerPlugInInfo getPlugInInfo(ReaderManagerPlugInType pType) const override;
+		QList<ReaderInfo> getReaderInfos(const ReaderFilter& pFilter = ReaderFilter()) const override;
+
+		void setIsScanRunning(bool pRunning);
 };
 
 
-MockReaderManager::MockReaderManager(const QVector<ReaderInfo>& pReaderInfos) :
-	mReaderInfos(pReaderInfos)
+MockReaderManager::MockReaderManager(const QList<ReaderInfo>& pReaderInfos)
+	: mReaderInfos(pReaderInfos)
+	, mIsScanRunning(false)
 {
 }
 
 
-QVector<ReaderInfo> MockReaderManager::getReaderInfos(const ReaderFilter& pFilter) const
+ReaderManagerPlugInInfo MockReaderManager::getPlugInInfo(ReaderManagerPlugInType pType) const
+{
+	ReaderManagerPlugInInfo info(pType);
+	info.setScanRunning(mIsScanRunning);
+	return info;
+}
+
+
+QList<ReaderInfo> MockReaderManager::getReaderInfos(const ReaderFilter& pFilter) const
 {
 	Q_UNUSED(pFilter)
 	return mReaderInfos;
 }
 
 
+void MockReaderManager::setIsScanRunning(bool pRunning)
+{
+	mIsScanRunning = pRunning;
+}
+
+
 class test_ReaderModel
 	: public QObject
 {
@@ -63,10 +82,10 @@ class test_ReaderModel
 	private:
 		QScopedPointer<MockReaderConfiguration> mMockReaderConfiguration;
 
-		QVector<UsbId> mUsbIds;
+		QList<UsbId> mUsbIds;
 		MockReaderDetector mMockReaderDetector;
 
-		QVector<ReaderInfo> mReaderInfos;
+		QList<ReaderInfo> mReaderInfos;
 		MockReaderManager mMockReaderManager;
 
 	private Q_SLOTS:
@@ -101,14 +120,14 @@ class test_ReaderModel
 		}
 
 
-		void test_01_settings()
+		void test_settings()
 		{
 			ReaderModel readerModel;
 			QCOMPARE(readerModel.rowCount(), 0);
 		}
 
 
-		void test_02_usbId()
+		void test_usbId()
 		{
 #if defined(Q_OS_FREEBSD)
 			QSKIP("No driver available for UsbId(0x0C4B, 0x0501) on FreeBSD");
@@ -124,7 +143,7 @@ class test_ReaderModel
 		}
 
 
-		void test_03_usbId_unknown()
+		void test_usbId_unknown()
 		{
 			mUsbIds += UsbId(0x1, 0x2);    // Unknown
 
@@ -133,29 +152,36 @@ class test_ReaderModel
 		}
 
 
-		void test_04_usbId_readerManager_equal()
-		{
-#if defined(Q_OS_FREEBSD)
-			QSKIP("No driver available for UsbId(0x04E6, 0x5790) on FreeBSD");
-#endif
-			mUsbIds += UsbId(0x04E6, 0x5790);    // Identiv Cloud 3700 F
-			mReaderInfos += ReaderInfo("Identiv CLOUD 3700 F Contactless Reader 0", ReaderManagerPlugInType::PCSC);
-
-			ReaderModel readerModel;
-			QCOMPARE(readerModel.rowCount(), 1);
-			const auto& index = readerModel.index(0, 0, QModelIndex());
-			QCOMPARE(readerModel.data(index, ReaderModel::UserRoles::READER_HTML_DESCRIPTION).toString(), tr("Driver installed"));
-		}
-
-
-		void test_05_usbId_readerManager_different()
+		void test_usbId_readerManager_different_scan_not_running()
 		{
 #if defined(Q_OS_FREEBSD)
 			QSKIP("No driver available for UsbId(0x04E6, 0x5790) on FreeBSD");
 #endif
 			mUsbIds += UsbId(0x0C4B, 0x0501);    // REINER SCT cyberJack RFID komfort
 			mUsbIds += UsbId(0x04E6, 0x5790);    // Identiv Cloud 3700 F
-			mReaderInfos += ReaderInfo("Identiv CLOUD 3700 F Contactless Reader 0", ReaderManagerPlugInType::PCSC);
+			mReaderInfos += ReaderInfo("Identiv CLOUD 3700 F Contactless Reader 0"_L1, ReaderManagerPlugInType::PCSC);
+
+			QModelIndex index;
+			ReaderModel readerModel;
+			QCOMPARE(readerModel.rowCount(), 2);
+			index = readerModel.index(0, 0, QModelIndex());
+			QCOMPARE(readerModel.data(index, ReaderModel::UserRoles::READER_HTML_DESCRIPTION).toString(), tr("The smartcard service of your system is not reachable."));
+			index = readerModel.index(1, 0, QModelIndex());
+			const auto& htmlDescription = readerModel.data(index, ReaderModel::UserRoles::READER_HTML_DESCRIPTION).toString();
+			QVERIFY(htmlDescription.startsWith(tr("The smartcard service of your system is not reachable.")));
+		}
+
+
+		void test_usbId_readerManager_different_scan_running()
+		{
+#if defined(Q_OS_FREEBSD)
+			QSKIP("No driver available for UsbId(0x04E6, 0x5790) on FreeBSD");
+#endif
+			mUsbIds += UsbId(0x0C4B, 0x0501);    // REINER SCT cyberJack RFID komfort
+			mUsbIds += UsbId(0x04E6, 0x5790);    // Identiv Cloud 3700 F
+			mReaderInfos += ReaderInfo("Identiv CLOUD 3700 F Contactless Reader 0"_L1, ReaderManagerPlugInType::PCSC);
+
+			mMockReaderManager.setIsScanRunning(true);
 
 			QModelIndex index;
 			ReaderModel readerModel;
@@ -164,20 +190,21 @@ class test_ReaderModel
 			QCOMPARE(readerModel.data(index, ReaderModel::UserRoles::READER_HTML_DESCRIPTION).toString(), tr("Driver installed"));
 			index = readerModel.index(1, 0, QModelIndex());
 			const auto& htmlDescription = readerModel.data(index, ReaderModel::UserRoles::READER_HTML_DESCRIPTION).toString();
-			QVERIFY(htmlDescription.startsWith(tr("The smartcard service of your system is not reachable.")));
+			QVERIFY(htmlDescription.startsWith(tr("No driver installed")));
+
 		}
 
 
-		void test_06_settings_readerManager_unknown()
+		void test_settings_readerManager_unknown()
 		{
-			mReaderInfos += ReaderInfo("Governikus Special Reader", ReaderManagerPlugInType::PCSC);
+			mReaderInfos += ReaderInfo("Governikus Special Reader"_L1, ReaderManagerPlugInType::PCSC);
 
 			ReaderModel readerModel;
 			QCOMPARE(readerModel.rowCount(), 1);
 		}
 
 
-		void test_07_translation()
+		void test_translation()
 		{
 			ReaderModel readerModel;
 			QSignalSpy spy(&readerModel, &ReaderModel::fireModelChanged);
