@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2015-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2015-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -13,6 +13,7 @@
 #include <QtCore>
 #include <QtTest>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 class test_TransmitResponse
@@ -38,7 +39,7 @@ class test_TransmitResponse
 			QVERIFY(!elem.contains("OutputAPDU"));
 
 			TransmitResponse responseWithApdu;
-			responseWithApdu.setMessageId("dummy");
+			responseWithApdu.setMessageId("dummy"_L1);
 			responseWithApdu.setOutputApdus(QByteArrayList{"bla"});
 			elem = responseWithApdu.marshall();
 
@@ -52,8 +53,8 @@ class test_TransmitResponse
 			response.setResult(ECardApiResult(GlobalStatus::Code::Workflow_Wrong_Parameter_Invocation));
 			response.setOutputApdus(QByteArrayList{"a", "b", "c"});
 			auto data = QString::fromLatin1(response.marshall());
-			data.replace(QRegularExpression("<wsa:MessageID>.*</wsa:MessageID>"), "<wsa:MessageID>STRIP ME</wsa:MessageID>");
-			QCOMPARE(data, QString::fromLatin1(TestFileHelper::readFile(":/paos/TransmitResponse.xml")));
+			data.replace(QRegularExpression("<wsa:MessageID>.*</wsa:MessageID>"_L1), "<wsa:MessageID>STRIP ME</wsa:MessageID>"_L1);
+			QCOMPARE(data, QString::fromLatin1(TestFileHelper::readFile(":/paos/TransmitResponse.xml"_L1)));
 		}
 
 
