@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 /*!
@@ -12,6 +12,7 @@
 
 #include <QtTest>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 char* toString(const SelfAuthenticationData::OrderedSelfData& pData)
@@ -65,10 +66,10 @@ class test_SelfAuthenticationData
 		void dateFormat()
 		{
 			SelfAuthenticationData::OrderedSelfData expected;
-			expected << qMakePair(QString("Date of birth"), QString("xx.xx.1946"));
-			expected << qMakePair(QString("Date of expiry"), QString("xx.11.2029"));
+			expected << qMakePair("Date of birth"_L1, "xx.xx.1946"_L1);
+			expected << qMakePair("Date of expiry"_L1, "xx.11.2029"_L1);
 
-			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataDateFormat.json");
+			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataDateFormat.json"_L1);
 			const SelfAuthenticationData selfAuthenticationData(data);
 			QVERIFY(selfAuthenticationData.isValid());
 			QVERIFY(selfAuthenticationData.getDateTime().isValid());
@@ -79,22 +80,22 @@ class test_SelfAuthenticationData
 		void orderedSelfData()
 		{
 			SelfAuthenticationData::OrderedSelfData expected;
-			expected << qMakePair(QString("Family name"), QStringLiteral("von Drebenbusch-Dalgo\u00DFen"));
-			expected << qMakePair(QString("Birth name"), QStringLiteral("Wei\u00dF"));
-			expected << qMakePair(QString("Given name(s)"), QStringLiteral("Hans-G\u00FCnther"));
-			expected << qMakePair(QString("Doctoral degree"), QString("Dr.eh.Dr."));
-			expected << qMakePair(QString("Date of birth"), QString("25.01.1946"));
-			expected << qMakePair(QString("Place of birth"), QString("BREMERHAVEN"));
-			expected << qMakePair(QString("Address"), QString("WEG NR.12 8E"));
-			expected << qMakePair(QString(), QString("22043 HAMBURG"));
-			expected << qMakePair(QString(), QString("D"));
-			expected << qMakePair(QString("Document type"), QString("ID"));
-			expected << qMakePair(QString("Nationality"), QString("D"));
-			expected << qMakePair(QString("Religious / artistic name"), QStringLiteral("Freiherr zu M\u00F6ckern-Windensberg"));
-			expected << qMakePair(QString("Issuing country"), QString("D"));
-			expected << qMakePair(QString("Date of expiry"), QString("30.11.2029"));
+			expected << qMakePair("Family name"_L1, QStringLiteral("von Drebenbusch-Dalgo\u00DFen"));
+			expected << qMakePair("Birth name"_L1, QStringLiteral("Wei\u00dF"));
+			expected << qMakePair("Given name(s)"_L1, QStringLiteral("Hans-G\u00FCnther"));
+			expected << qMakePair("Doctoral degree"_L1, "Dr.eh.Dr."_L1);
+			expected << qMakePair("Date of birth"_L1, "25.01.1946"_L1);
+			expected << qMakePair("Place of birth"_L1, "BREMERHAVEN"_L1);
+			expected << qMakePair("Address"_L1, "WEG NR.12 8E"_L1);
+			expected << qMakePair(QString(), "22043 HAMBURG"_L1);
+			expected << qMakePair(QString(), "D"_L1);
+			expected << qMakePair("Document type"_L1, "ID"_L1);
+			expected << qMakePair("Nationality"_L1, "D"_L1);
+			expected << qMakePair("Religious / artistic name"_L1, QStringLiteral("Freiherr zu M\u00F6ckern-Windensberg"));
+			expected << qMakePair("Issuing country"_L1, "D"_L1);
+			expected << qMakePair("Date of expiry"_L1, "30.11.2029"_L1);
 
-			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataID.json");
+			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataID.json"_L1);
 			SelfAuthenticationData selfAuthenticationData(data);
 			QVERIFY(selfAuthenticationData.isValid());
 			QVERIFY(selfAuthenticationData.getDateTime().isValid());
@@ -104,72 +105,72 @@ class test_SelfAuthenticationData
 
 		void parsedValues()
 		{
-			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationData.json");
+			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationData.json"_L1);
 			SelfAuthenticationData selfAuthenticationData(data);
 			QVERIFY(selfAuthenticationData.isValid());
 
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfExpiry), QString("2020-10-31+01:00"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DocumentType), QString("TA"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::IssuingState), QString("D"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::Nationality), QString("AZE"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfExpiry), "2020-10-31+01:00"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DocumentType), "TA"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::IssuingState), "D"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::Nationality), "AZE"_L1);
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::GivenNames), QStringLiteral("ANDR\u00c9"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::FamilyNames), QString("MUSTERMANN"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::FamilyNames), "MUSTERMANN"_L1);
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::ArtisticName), QString());
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::AcademicTitle), QString());
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::BirthName), QString());
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfBirth), QString("1981-06-17+02:00"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfBirth), QString("FRANKFURT (ODER)"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfBirth), "1981-06-17+02:00"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfBirth), "FRANKFURT (ODER)"_L1);
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceStreet), QStringLiteral("EHM-WELK-STRA\u00dfE 33"));
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCity), QStringLiteral("L\u00dcBBENAU/SPREEWALD"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCountry), QString("D"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceZipCode), QString("03222"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCountry), "D"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceZipCode), "03222"_L1);
 		}
 
 
 		void parsedValuesNoAddress()
 		{
-			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataNoAddress.json");
+			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataNoAddress.json"_L1);
 			SelfAuthenticationData selfAuthenticationData(data);
 			QVERIFY(selfAuthenticationData.isValid());
 
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DocumentType), QString("TP"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::IssuingState), QString("D"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::GivenNames), QString("KARL"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::FamilyNames), QString("HILLEBRANDT"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DocumentType), "TP"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::IssuingState), "D"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::GivenNames), "KARL"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::FamilyNames), "HILLEBRANDT"_L1);
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::ArtisticName), QStringLiteral("GRAF V. L\u00DDSKY"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::AcademicTitle), QString("DR.HC."));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::BirthName), QString("This data has not been stored in this chip generation."));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfBirth), QString("1952-06-17+01:00"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfBirth), QString("TRIER"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::AcademicTitle), "DR.HC."_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::BirthName), "This data has not been stored in this chip generation."_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfBirth), "1952-06-17+01:00"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfBirth), "TRIER"_L1);
 
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceStreet), QString());
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCountry), QString());
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceZipCode), QString());
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceNoPlaceInfo), QString("keine Hauptwohnung in Deutschland"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceNoPlaceInfo), "keine Hauptwohnung in Deutschland"_L1);
 		}
 
 
 		void parsedValuesNoStreet()
 		{
-			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataNoStreet.json");
+			const auto& data = TestFileHelper::readFile(":/self/SelfAuthenticationDataNoStreet.json"_L1);
 			SelfAuthenticationData selfAuthenticationData(data);
 			QVERIFY(selfAuthenticationData.isValid());
 
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DocumentType), QString("TP"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::IssuingState), QString("D"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::GivenNames), QString("ANNEKATHRIN"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::FamilyNames), QString("LERCH"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DocumentType), "TP"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::IssuingState), "D"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::GivenNames), "ANNEKATHRIN"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::FamilyNames), "LERCH"_L1);
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::ArtisticName), QString());
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::AcademicTitle), QString());
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::BirthName), QString());
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfBirth), QString("1976-07-05+01:00"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::DateOfBirth), "1976-07-05+01:00"_L1);
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfBirth), QStringLiteral("BAD K\u00D6NIGSHOFEN I. GRABFELD"));
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCity), QStringLiteral("L\u00DCBBENAU/SPREEWALD"));
 
 			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceStreet), QString());
 
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCountry), QString("D"));
-			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceZipCode), QString("06108"));
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceCountry), "D"_L1);
+			QCOMPARE(selfAuthenticationData.getValue(SelfAuthData::PlaceOfResidenceZipCode), "06108"_L1);
 		}
 
 
