@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "states/StateCheckRefreshAddress.h"
@@ -16,6 +16,7 @@
 
 #include <QtTest>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 
@@ -79,25 +80,25 @@ class test_StateCheckRefreshAddress
 		void run_data()
 		{
 			QTest::addColumn<QByteArray>("redirectUrl");
-			QTest::addColumn<QString>("tcTokenUrl");
+			QTest::addColumn<QLatin1String>("tcTokenUrl");
 			QTest::addColumn<QStringList>("messages");
 
-			const QStringList msg1(QString("Invalid RefreshAddress: test"));
-			const QStringList msg2(QString("Invalid RefreshAddress: http://service.governikus.de/loggedin?7eb39f62"));
-			const QStringList msg3 = {QString("Subject URL from AT CVC (eService certificate) description: \"https://service.governikus.de\""), QString("Current redirect URL: \"https://service.governikus.de/loggedin?7eb39f62\""), QString("SOP-Check succeeded, abort process.")};
-			const QStringList msg4 = {QString("Subject URL from AT CVC (eService certificate) description: \"https://governikus.de\""), QString("Current redirect URL: \"https://service.governikus.de/loggedin?7eb39f62\""), QString("SOP-Check failed, start process.")};
+			const QStringList msg1("Invalid RefreshAddress: test"_L1);
+			const QStringList msg2("Invalid RefreshAddress: http://service.governikus.de/loggedin?7eb39f62"_L1);
+			const QStringList msg3 = {"Subject URL from AT CVC (eService certificate) description: \"https://service.governikus.de\""_L1, "Current redirect URL: \"https://service.governikus.de/loggedin?7eb39f62\""_L1, "SOP-Check succeeded, abort process."_L1};
+			const QStringList msg4 = {"Subject URL from AT CVC (eService certificate) description: \"https://governikus.de\""_L1, "Current redirect URL: \"https://service.governikus.de/loggedin?7eb39f62\""_L1, "SOP-Check failed, start process."_L1};
 
-			QTest::newRow("urlInvalid") << QByteArray("test") << QString() << msg1;
-			QTest::newRow("notHttps") << QByteArray("http://service.governikus.de/loggedin?7eb39f62") << QString("http://service.governikus.de") << msg2;
-			QTest::newRow("matchingSameOriginPolicy") << QByteArray("https://service.governikus.de/loggedin?7eb39f62") << QString("https://service.governikus.de") << msg3;
-			QTest::newRow("notMatchingSameOriginPolicy") << QByteArray("https://service.governikus.de/loggedin?7eb39f62") << QString("https://governikus.de") << msg4;
+			QTest::newRow("urlInvalid") << QByteArray("test") << QLatin1String() << msg1;
+			QTest::newRow("notHttps") << QByteArray("http://service.governikus.de/loggedin?7eb39f62") << "http://service.governikus.de"_L1 << msg2;
+			QTest::newRow("matchingSameOriginPolicy") << QByteArray("https://service.governikus.de/loggedin?7eb39f62") << "https://service.governikus.de"_L1 << msg3;
+			QTest::newRow("notMatchingSameOriginPolicy") << QByteArray("https://service.governikus.de/loggedin?7eb39f62") << "https://governikus.de"_L1 << msg4;
 		}
 
 
 		void run()
 		{
 			QFETCH(QByteArray, redirectUrl);
-			QFETCH(QString, tcTokenUrl);
+			QFETCH(QLatin1String, tcTokenUrl);
 			QFETCH(QStringList, messages);
 
 			QSignalSpy spyContinue(mState.data(), &StateCheckRefreshAddress::fireContinue);
@@ -128,7 +129,7 @@ class test_StateCheckRefreshAddress
 
 		void mappingToCommunicationError()
 		{
-			const QVector<GlobalStatus::Code> states = QVector<GlobalStatus::Code>()
+			const QList<GlobalStatus::Code> states = QList<GlobalStatus::Code>()
 					<< GlobalStatus::Code::Network_Ssl_Establishment_Error
 					<< GlobalStatus::Code::Network_Ssl_Establishment_Error
 					<< GlobalStatus::Code::Workflow_Network_Ssl_Connection_Unsupported_Algorithm_Or_Length
@@ -151,7 +152,7 @@ class test_StateCheckRefreshAddress
 
 		void sendGetRequestWithoutAnyAdditionalParameters()
 		{
-			QUrl redirectUrl("http://localhost:12345/test_StateCheckRefreshAddress/");
+			QUrl redirectUrl("http://localhost:12345/test_StateCheckRefreshAddress/"_L1);
 			mAuthContext->setStatus(GlobalStatus::Code::Workflow_Server_Incomplete_Information_Provided);
 			mState->mUrl = redirectUrl;
 
@@ -193,9 +194,9 @@ class test_StateCheckRefreshAddress
 			QVERIFY(!mState->isMatchingSameOriginPolicyInDevMode());
 
 			Env::getSingleton<AppSettings>()->getGeneralSettings().setDeveloperMode(true);
-			const QUrl pUrlHttps("https://invalidhost/");
-			const QUrl pUrlHttp("http://localhost:12345/test_StateCheckRefreshAddress/");
-			const QUrl pSubjectUrl("http://localhost:12345/test_StateCheckRefreshAddress/");
+			const QUrl pUrlHttps("https://invalidhost/"_L1);
+			const QUrl pUrlHttp("http://localhost:12345/test_StateCheckRefreshAddress/"_L1);
+			const QUrl pSubjectUrl("http://localhost:12345/test_StateCheckRefreshAddress/"_L1);
 
 			mState->mUrl = pUrlHttps;
 			mState->mSubjectUrl = pSubjectUrl;
@@ -211,10 +212,10 @@ class test_StateCheckRefreshAddress
 
 		void determinateSubjectUrl()
 		{
-			const QUrl tcTokenUrl("http://invalidhost/");
+			const QUrl tcTokenUrl("http://invalidhost/"_L1);
 			mAuthContext->setTcTokenUrl(tcTokenUrl);
 
-			QByteArray content = TestFileHelper::readFile(":/paos/DIDAuthenticateEAC1.xml");
+			QByteArray content = TestFileHelper::readFile(":/paos/DIDAuthenticateEAC1.xml"_L1);
 			QSharedPointer<DIDAuthenticateEAC1> eac1(static_cast<DIDAuthenticateEAC1*>(DidAuthenticateEac1Parser().parse(content)));
 
 			SDK_MODE(false);
@@ -223,7 +224,7 @@ class test_StateCheckRefreshAddress
 			QCOMPARE(mState->determineSubjectUrl(), tcTokenUrl);
 
 			mAuthContext->setDidAuthenticateEac1(eac1);
-			QCOMPARE(mState->determineSubjectUrl(), QUrl("https://test.governikus-eid.de"));
+			QCOMPARE(mState->determineSubjectUrl(), QUrl("https://test.governikus-eid.de"_L1));
 
 			Env::getSingleton<AppSettings>()->getGeneralSettings().setDeveloperMode(true);
 			QCOMPARE(mState->determineSubjectUrl(), tcTokenUrl);
@@ -265,19 +266,19 @@ class test_StateCheckRefreshAddress
 			QTest::addColumn<QUrl>("redirectUrl");
 			QTest::addColumn<bool>("developerMode");
 
-			QTest::newRow("http service unavailable") << QNetworkReply::NetworkError::ServiceUnavailableError << GlobalStatus::Code::Network_ServiceUnavailable << FailureCode::Reason::Check_Refresh_Address_Service_Unavailable << 503 << QUrl("http://governikus.com/") << false;
-			QTest::newRow("http internal server error") << QNetworkReply::NetworkError::InternalServerError << GlobalStatus::Code::Network_ServerError << FailureCode::Reason::Check_Refresh_Address_Server_Error << 500 << QUrl("http://governikus.com/") << false;
-			QTest::newRow("http not found") << QNetworkReply::NetworkError::ContentNotFoundError << GlobalStatus::Code::Network_ClientError << FailureCode::Reason::Check_Refresh_Address_Client_Error << 404 << QUrl("https://governikus.com/") << false;
-			QTest::newRow("http other error") << QNetworkReply::NetworkError::ProtocolUnknownError << GlobalStatus::Code::Network_Other_Error << FailureCode::Reason::Check_Refresh_Address_Unknown_Network_Error << 304 << QUrl("http://governikus.com/") << false;
+			QTest::newRow("http service unavailable") << QNetworkReply::NetworkError::ServiceUnavailableError << GlobalStatus::Code::Network_ServiceUnavailable << FailureCode::Reason::Check_Refresh_Address_Service_Unavailable << 503 << QUrl("http://governikus.com/"_L1) << false;
+			QTest::newRow("http internal server error") << QNetworkReply::NetworkError::InternalServerError << GlobalStatus::Code::Network_ServerError << FailureCode::Reason::Check_Refresh_Address_Server_Error << 500 << QUrl("http://governikus.com/"_L1) << false;
+			QTest::newRow("http not found") << QNetworkReply::NetworkError::ContentNotFoundError << GlobalStatus::Code::Network_ClientError << FailureCode::Reason::Check_Refresh_Address_Client_Error << 404 << QUrl("https://governikus.com/"_L1) << false;
+			QTest::newRow("http other error") << QNetworkReply::NetworkError::ProtocolUnknownError << GlobalStatus::Code::Network_Other_Error << FailureCode::Reason::Check_Refresh_Address_Unknown_Network_Error << 304 << QUrl("http://governikus.com/"_L1) << false;
 			QTest::newRow("timeout") << QNetworkReply::NetworkError::TimeoutError << GlobalStatus::Code::Network_TimeOut << FailureCode::Reason::Check_Refresh_Address_Service_Timeout << 2 << QUrl() << false;
-			QTest::newRow("proxy error") << QNetworkReply::NetworkError::ProxyNotFoundError << GlobalStatus::Code::Network_Proxy_Error << FailureCode::Reason::Check_Refresh_Address_Proxy_Error << 0 << QUrl("test") << false;
-			QTest::newRow("ssl error") << QNetworkReply::NetworkError::SslHandshakeFailedError << GlobalStatus::Code::Network_Ssl_Establishment_Error << FailureCode::Reason::Check_Refresh_Address_Fatal_Tls_Error_After_Reply << 1 << QUrl("https://governikus.com/") << false;
-			QTest::newRow("other error") << QNetworkReply::NetworkError::OperationCanceledError << GlobalStatus::Code::Network_Other_Error << FailureCode::Reason::Check_Refresh_Address_Unknown_Network_Error << 2 << QUrl("https://governikus.com/") << false;
-			QTest::newRow("no error unexpected status") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Expected_Redirect << FailureCode::Reason::Check_Refresh_Address_Invalid_Http_Response << 2 << QUrl("https://governikus.com/") << false;
+			QTest::newRow("proxy error") << QNetworkReply::NetworkError::ProxyNotFoundError << GlobalStatus::Code::Network_Proxy_Error << FailureCode::Reason::Check_Refresh_Address_Proxy_Error << 0 << QUrl("test"_L1) << false;
+			QTest::newRow("ssl error") << QNetworkReply::NetworkError::SslHandshakeFailedError << GlobalStatus::Code::Network_Ssl_Establishment_Error << FailureCode::Reason::Check_Refresh_Address_Fatal_Tls_Error_After_Reply << 1 << QUrl("https://governikus.com/"_L1) << false;
+			QTest::newRow("other error") << QNetworkReply::NetworkError::OperationCanceledError << GlobalStatus::Code::Network_Other_Error << FailureCode::Reason::Check_Refresh_Address_Unknown_Network_Error << 2 << QUrl("https://governikus.com/"_L1) << false;
+			QTest::newRow("no error unexpected status") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Expected_Redirect << FailureCode::Reason::Check_Refresh_Address_Invalid_Http_Response << 2 << QUrl("https://governikus.com/"_L1) << false;
 			QTest::newRow("no error empty url") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Empty_Redirect_Url << FailureCode::Reason::Check_Refresh_Address_Empty << 302 << QUrl() << false;
-			QTest::newRow("no error invalid url") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Malformed_Redirect_Url << FailureCode::Reason::Check_Refresh_Address_Invalid_Url << 302 << QUrl("://://") << false;
-			QTest::newRow("no error http") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Invalid_Scheme << FailureCode::Reason::Check_Refresh_Address_No_Https_Scheme << 302 << QUrl("http://governikus.com/") << false;
-			QTest::newRow("no error http developer mode") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::No_Error << FailureCode::Reason::Check_Refresh_Address_No_Https_Scheme << 302 << QUrl("http://governikus.com/") << true;
+			QTest::newRow("no error invalid url") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Malformed_Redirect_Url << FailureCode::Reason::Check_Refresh_Address_Invalid_Url << 302 << QUrl("://://"_L1) << false;
+			QTest::newRow("no error http") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::Workflow_Network_Invalid_Scheme << FailureCode::Reason::Check_Refresh_Address_No_Https_Scheme << 302 << QUrl("http://governikus.com/"_L1) << false;
+			QTest::newRow("no error http developer mode") << QNetworkReply::NetworkError::NoError << GlobalStatus::Code::No_Error << FailureCode::Reason::Check_Refresh_Address_No_Https_Scheme << 302 << QUrl("http://governikus.com/"_L1) << true;
 		}
 
 
@@ -317,7 +318,7 @@ class test_StateCheckRefreshAddress
 		{
 			SDK_MODE(false);
 			Env::getSingleton<AppSettings>()->getGeneralSettings().setDeveloperMode(true);
-			const QUrl url("http://governikus.de/");
+			const QUrl url("http://governikus.de/"_L1);
 			mState->mUrl = url;
 			QTest::ignoreMessage(QtWarningMsg, "Refresh URL is http only. Certificate check skipped.");
 			mState->fetchServerCertificate();
@@ -327,7 +328,7 @@ class test_StateCheckRefreshAddress
 		void fetchServerCertificate_AlreadyVerified()
 		{
 			Env::getSingleton<AppSettings>()->getGeneralSettings().setDeveloperMode(false);
-			const QUrl url("https://governikus.de/");
+			const QUrl url("https://governikus.de/"_L1);
 			mState->mUrl = url;
 			mState->mVerifiedRefreshUrlHosts.insert(0, url);
 			QTest::ignoreMessage(QtDebugMsg, "SSL certificate already collected for QUrl(\"https://governikus.de/\")");
@@ -338,7 +339,7 @@ class test_StateCheckRefreshAddress
 		void fetchServerCertificate()
 		{
 			Env::getSingleton<AppSettings>()->getGeneralSettings().setDeveloperMode(false);
-			const QUrl url("https://governikus.de/");
+			const QUrl url("https://governikus.de/"_L1);
 			mState->mUrl = url;
 			QTest::ignoreMessage(QtDebugMsg, "Fetch TLS certificate for URL QUrl(\"https://governikus.de/\")");
 			mState->fetchServerCertificate();
@@ -347,7 +348,7 @@ class test_StateCheckRefreshAddress
 
 		void doneSuccess()
 		{
-			const QUrl url("https://governikus.de/");
+			const QUrl url("https://governikus.de/"_L1);
 			mState->mUrl = url;
 			QSignalSpy spy(mState.data(), &StateCheckRefreshAddress::fireContinue);
 
