@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2018-2023 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2018-2024 Governikus GmbH & Co. KG, Germany
  */
 
 #include "states/StateSendWhitelistSurvey.h"
@@ -17,7 +17,7 @@
 
 #include <QtTest>
 
-
+using namespace Qt::Literals::StringLiterals;
 using namespace governikus;
 
 class MockSecureStorage
@@ -46,7 +46,7 @@ class test_StateSendWhitelistSurvey
 	private Q_SLOTS:
 		void init()
 		{
-			mContext.reset(new TestAuthContext(":/paos/DIDAuthenticateEAC1.xml"));
+			mContext.reset(new TestAuthContext(":/paos/DIDAuthenticateEAC1.xml"_L1));
 			mState.reset(StateBuilder::createState<StateSendWhitelistSurvey>(mContext));
 			mState->onEntry(nullptr);
 		}
@@ -110,11 +110,11 @@ class test_StateSendWhitelistSurvey
 			QTest::addColumn<int>("spyCounter");
 			QTest::addColumn<QUrl>("url");
 
-			QTest::newRow("successful") << quint16(25000) << 1 << QUrl("http://localhost:25000");
-			QTest::newRow("invalidPort") << quint16(1515) << 0 << QUrl("http://localhost:25000");
-			QTest::newRow("emptyPort") << quint16() << 0 << QUrl("http://localhost:25000");
-			QTest::newRow("emptyPortinUrl") << quint16(1515) << 0 << QUrl("http://localhost");
-			QTest::newRow("invalidHost") << quint16(25000) << 0 << QUrl("http://test:25000");
+			QTest::newRow("successful") << quint16(25000) << 1 << QUrl("http://localhost:25000"_L1);
+			QTest::newRow("invalidPort") << quint16(1515) << 0 << QUrl("http://localhost:25000"_L1);
+			QTest::newRow("emptyPort") << quint16() << 0 << QUrl("http://localhost:25000"_L1);
+			QTest::newRow("emptyPortinUrl") << quint16(1515) << 0 << QUrl("http://localhost"_L1);
+			QTest::newRow("invalidHost") << quint16(25000) << 0 << QUrl("http://test:25000"_L1);
 		}
 
 
@@ -129,7 +129,7 @@ class test_StateSendWhitelistSurvey
 			Env::getSingleton<AppSettings>()->getGeneralSettings().setDeviceSurveyPending(true);
 
 			const auto& surveyModel = Env::getSingleton<SurveyModel>();
-			ReaderInfo readerInfo("reader", ReaderManagerPlugInType::NFC, CardInfo(CardType::EID_CARD));
+			ReaderInfo readerInfo("reader"_L1, ReaderManagerPlugInType::NFC, CardInfo(CardType::EID_CARD));
 			readerInfo.setMaxApduLength(0);
 			surveyModel->setReaderInfo(readerInfo);
 			surveyModel->setAuthWasSuccessful(true);
@@ -140,7 +140,7 @@ class test_StateSendWhitelistSurvey
 			HttpServer server(port);
 			QSignalSpy spy(&server, &HttpServer::fireNewHttpRequest);
 
-			const QString name("reader");
+			const QString name("reader"_L1);
 			mContext->setReaderName(name);
 			MockSecureStorage storage(url);
 			Env::set(SecureStorage::staticMetaObject, &storage);
@@ -154,7 +154,7 @@ class test_StateSendWhitelistSurvey
 			QString message;
 			for (int i = 0; i < logSpy.size(); i++)
 			{
-				if (logSpy.at(i).at(0).toString().contains("Sent survey to whitelist server:"))
+				if (logSpy.at(i).at(0).toString().contains("Sent survey to whitelist server:"_L1))
 				{
 					surveySent = true;
 					message = logSpy.at(i).at(0).toString();
@@ -163,31 +163,31 @@ class test_StateSendWhitelistSurvey
 			}
 
 			QVERIFY(surveySent);
-			QVERIFY(message.contains("AusweisAppVersionNumber"));
-			QVERIFY(message.contains("ModelName"));
-			QVERIFY(message.contains("ModelNumber"));
-			QVERIFY(message.contains("Rom"));
-			QVERIFY(message.contains("OsVersion"));
-			QVERIFY(message.contains("BuildNumber"));
-			QVERIFY(message.contains("KernelVersion"));
-			QVERIFY(message.contains("\"MaximumNfcPacketLength\": 0"));
-			QVERIFY(message.contains("Vendor"));
-			QVERIFY(message.contains("NfcTagType"));
+			QVERIFY(message.contains("AusweisAppVersionNumber"_L1));
+			QVERIFY(message.contains("ModelName"_L1));
+			QVERIFY(message.contains("ModelNumber"_L1));
+			QVERIFY(message.contains("Rom"_L1));
+			QVERIFY(message.contains("OsVersion"_L1));
+			QVERIFY(message.contains("BuildNumber"_L1));
+			QVERIFY(message.contains("KernelVersion"_L1));
+			QVERIFY(message.contains("\"MaximumNfcPacketLength\": 0"_L1));
+			QVERIFY(message.contains("Vendor"_L1));
+			QVERIFY(message.contains("NfcTagType"_L1));
 
 			if (spyCounter != 0)
 			{
 				const QSharedPointer<HttpRequest> request = spy.at(0).at(0).value<QSharedPointer<HttpRequest>>();
-				QCOMPARE(request->getUrl(), QUrl("/new"));
+				QCOMPARE(request->getUrl(), QUrl("/new"_L1));
 				QCOMPARE(request->getHeader(QByteArray("host")), QByteArray("localhost:25000"));
 				QCOMPARE(request->getHeader(QByteArray("content-type")), QByteArray("application/json; charset=UTF-8"));
 				QJsonDocument json = QJsonDocument::fromJson(request->getBody());
 				QJsonObject jsonObject = json.object();
-				QVERIFY(jsonObject.contains("AusweisAppVersionNumber"));
-				QVERIFY(jsonObject.contains("ModelName"));
-				QVERIFY(jsonObject.contains("ModelNumber"));
-				QVERIFY(jsonObject.contains("Rom"));
-				QVERIFY(jsonObject.contains("Vendor"));
-				QVERIFY(jsonObject.contains("NfcTagType"));
+				QVERIFY(jsonObject.contains("AusweisAppVersionNumber"_L1));
+				QVERIFY(jsonObject.contains("ModelName"_L1));
+				QVERIFY(jsonObject.contains("ModelNumber"_L1));
+				QVERIFY(jsonObject.contains("Rom"_L1));
+				QVERIFY(jsonObject.contains("Vendor"_L1));
+				QVERIFY(jsonObject.contains("NfcTagType"_L1));
 			}
 		}
 
